@@ -102,7 +102,7 @@ static int sox_auencodingandsize(uint32_t sun_encoding, sox_encoding_t * encodin
             *size = SOX_SIZE_32BIT;
             break;
     default:
-            sox_debug("encoding: 0x%lx", sun_encoding);
+            sox_debug("encoding: 0x%x", sun_encoding);
             return(SOX_EOF);
     }
     return(SOX_SUCCESS);
@@ -331,7 +331,7 @@ static int unpack_input(sox_format_t * ft, unsigned char *code)
         return (p->in_bits > 0);
 }
 
-static sox_size_t sox_auread(sox_format_t * ft, sox_ssample_t *buf, sox_size_t samp)
+static sox_size_t sox_auread(sox_format_t * ft, sox_sample_t *buf, sox_size_t samp)
 {
         au_t p = (au_t ) ft->priv;
         unsigned char code;
@@ -349,7 +349,7 @@ static sox_size_t sox_auread(sox_format_t * ft, sox_ssample_t *buf, sox_size_t s
         return done;
 }
 
-static sox_size_t sox_auwrite(sox_format_t * ft, const sox_ssample_t *buf, sox_size_t samp)
+static sox_size_t sox_auwrite(sox_format_t * ft, const sox_sample_t *buf, sox_size_t samp)
 {
         au_t p = (au_t ) ft->priv;
         p->data_size += samp * ft->signal.size;
@@ -443,7 +443,7 @@ static void auwriteheader(sox_format_t * ft, sox_size_t data_size)
          * useful when there is no comments.
          */
         if (ft->comment == NULL)
-                ft->comment = xstrdup("SOX");
+                ft->comment = xstrdup("SoX");
 
         hdr_size = SUN_HDRSIZE;
 
