@@ -66,7 +66,7 @@ typedef struct biquad
   double b2, b1, b0;       /* Filter coefficients */
   double a2, a1, a0;       /* Filter coefficients */
 
-  sox_ssample_t i1, i2;      /* Filter memory */
+  sox_sample_t i1, i2;      /* Filter memory */
   double      o1, o2;      /* Filter memory */
 } * biquad_t;
 
@@ -78,7 +78,7 @@ int sox_biquad_getopts(sox_effect_t * effp, int n, char **argv,
     int min_args, int max_args, int fc_pos, int width_pos, int gain_pos,
     char const * allowed_width_types, filter_t filter_type);
 int sox_biquad_start(sox_effect_t * effp);
-int sox_biquad_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssample_t *obuf, 
+int sox_biquad_flow(sox_effect_t * effp, const sox_sample_t *ibuf, sox_sample_t *obuf, 
                         sox_size_t *isamp, sox_size_t *osamp);
 
 #undef sox_fail
