@@ -167,13 +167,13 @@ static int sox_echos_start(sox_effect_t * effp)
  * Processed signed long samples from ibuf to obuf.
  * Return number of samples processed.
  */
-static int sox_echos_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssample_t *obuf, 
+static int sox_echos_flow(sox_effect_t * effp, const sox_sample_t *ibuf, sox_sample_t *obuf, 
                 sox_size_t *isamp, sox_size_t *osamp)
 {
         echos_t echos = (echos_t) effp->priv;
         int j;
         double d_in, d_out;
-        sox_ssample_t out;
+        sox_sample_t out;
         sox_size_t len = min(*isamp, *osamp);
         *isamp = *osamp = len;
 
@@ -187,7 +187,7 @@ static int sox_echos_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ss
                 }
                 /* Adjust the output volume and size to 24 bit */
                 d_out = d_out * echos->out_gain;
-                out = SOX_24BIT_CLIP_COUNT((sox_ssample_t) d_out, effp->clips);
+                out = SOX_24BIT_CLIP_COUNT((sox_sample_t) d_out, effp->clips);
                 *obuf++ = out * 256;
                 /* Mix decay of delays and input */
                 for ( j = 0; j < echos->num_delays; j++ ) {
@@ -209,11 +209,11 @@ static int sox_echos_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ss
 /*
  * Drain out reverb lines. 
  */
-static int sox_echos_drain(sox_effect_t * effp, sox_ssample_t *obuf, sox_size_t *osamp)
+static int sox_echos_drain(sox_effect_t * effp, sox_sample_t *obuf, sox_size_t *osamp)
 {
         echos_t echos = (echos_t) effp->priv;
         double d_in, d_out;
-        sox_ssample_t out;
+        sox_sample_t out;
         int j;
         sox_size_t done;
 
@@ -227,7 +227,7 @@ static int sox_echos_drain(sox_effect_t * effp, sox_ssample_t *obuf, sox_size_t
                 }
                 /* Adjust the output volume and size to 24 bit */
                 d_out = d_out * echos->out_gain;
-                out = SOX_24BIT_CLIP_COUNT((sox_ssample_t) d_out, effp->clips);
+                out = SOX_24BIT_CLIP_COUNT((sox_sample_t) d_out, effp->clips);
                 *obuf++ = out * 256;
                 /* Mix decay of delays and input */
                 for ( j = 0; j < echos->num_delays; j++ ) {
