@@ -203,8 +203,8 @@ static int sox_flanger_start(sox_effect_t * effp)
 
 
 
-static int sox_flanger_flow(sox_effect_t * effp, sox_ssample_t const * ibuf,
-    sox_ssample_t * obuf, sox_size_t * isamp, sox_size_t * osamp)
+static int sox_flanger_flow(sox_effect_t * effp, sox_sample_t const * ibuf,
+    sox_sample_t * obuf, sox_size_t * isamp, sox_size_t * osamp)
 {
   flanger_t f = (flanger_t) effp->priv;
   int c, channels = effp->ininfo.channels;
