@@ -1,6 +1,3 @@
-#include "soxconfig.h"
-#ifndef HAVE_GETOPT_LONG
-
 /* Getopt for GNU.
    NOTE: getopt is now part of the C library, so if you don't know what
    "Keep this file name-space clean" means, talk to drepper@gnu.org
@@ -1280,4 +1277,3 @@ main (argc, argv)
 }
 
 #endif /* TEST */
-#endif /* HAVE_GETOPT_LONG */
