@@ -23,7 +23,7 @@
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include "st_i.h"
+#include "sox_i.h"
 #include "ima_rw.h"
 /*
  *
@@ -65,12 +65,12 @@ void initImaTable(void)
 }
 
 static void ImaExpandS(
-        int ch,             /* channel number to decode, REQUIRE 0 <= ch < chans  */
-        int chans,          /* total channels             */
+        unsigned ch,             /* channel number to decode, REQUIRE 0 <= ch < chans  */
+        unsigned chans,          /* total channels             */
         const unsigned char *ibuff,/* input buffer[blockAlign]   */
         SAMPL *obuff,       /* obuff[n] will be output samples */
         int n,              /* samples to decode PER channel, REQUIRE n % 8 == 1  */
-        int o_inc           /* index difference between successive output samples */
+        unsigned o_inc           /* index difference between successive output samples */
 )
 {
         const unsigned char *ip;
@@ -83,7 +83,7 @@ static void ImaExpandS(
         val = (short)(ip[0] + (ip[1]<<8)); /* need cast for sign-extend */
         state = ip[2];
         if (state > ISSTMAX) {
-                st_warn("IMA_ADPCM block ch%d initial-state (%d) out of range", ch, state);
+                sox_warn("IMA_ADPCM block ch%d initial-state (%d) out of range", ch, state);
                 state = 0;
         }
         /* specs say to ignore ip[3] , but write it as 0 */
@@ -133,34 +133,34 @@ static void ImaExpandS(
 
 /* ImaBlockExpandI() outputs interleaved samples into one output buffer */
 void ImaBlockExpandI(
-        int chans,          /* total channels             */
+        unsigned chans,          /* total channels             */
         const unsigned char *ibuff,/* input buffer[blockAlign]   */
         SAMPL *obuff,       /* output samples, n*chans    */
         int n               /* samples to decode PER channel, REQUIRE n % 8 == 1  */
 )
 {
-        int ch;
+        unsigned ch;
         for (ch=0; ch<chans; ch++)
                 ImaExpandS(ch, chans, ibuff, obuff+ch, n, chans);
 }
 
 /* ImaBlockExpandM() outputs non-interleaved samples into chan separate output buffers */
 void ImaBlockExpandM(
-        int chans,          /* total channels             */
+        unsigned chans,          /* total channels             */
         const unsigned char *ibuff,/* input buffer[blockAlign]   */
         SAMPL **obuffs,     /* chan output sample buffers, each takes n samples */
         int n               /* samples to decode PER channel, REQUIRE n % 8 == 1  */
 )
 {
-        int ch;
+        unsigned ch;
         for (ch=0; ch<chans; ch++)
                 ImaExpandS(ch, chans, ibuff, obuffs[ch], n, 1);
 }
 
 static int ImaMashS(
-        int ch,             /* channel number to encode, REQUIRE 0 <= ch < chans  */
-        int chans,          /* total channels */
-        SAMPL v0,           /* value to use as starting prediction0 */
+        unsigned ch,             /* channel number to encode, REQUIRE 0 <= ch < chans  */
+        unsigned chans,          /* total channels */
+        int v0,           /* value to use as starting prediction0 */
         const SAMPL *ibuff, /* ibuff[] is interleaved input samples */
         int n,              /* samples to encode PER channel, REQUIRE n % 8 == 1 */
         int *st,            /* input/output state, REQUIRE 0 <= *st <= ISSTMAX */
@@ -245,8 +245,8 @@ static int ImaMashS(
 
 /* mash one channel... if you want to use opt>0, 9 is a reasonable value */
 inline static void ImaMashChannel(
-        int ch,             /* channel number to encode, REQUIRE 0 <= ch < chans  */
-        int chans,          /* total channels */
+        unsigned ch,             /* channel number to encode, REQUIRE 0 <= ch < chans  */
+        unsigned chans,          /* total channels */
         const SAMPL *ip,    /* ip[] is interleaved input samples */
         int n,              /* samples to encode PER channel, REQUIRE n % 8 == 1 */
         int *st,            /* input/output state, REQUIRE 0 <= *st <= ISSTMAX */
@@ -299,7 +299,7 @@ inline static void ImaMashChannel(
 
 /* mash one block.  if you want to use opt>0, 9 is a reasonable value */
 void ImaBlockMashI(
-        int chans,          /* total channels */
+        unsigned chans,          /* total channels */
         const SAMPL *ip,    /* ip[] is interleaved input samples */
         int n,              /* samples to encode PER channel, REQUIRE n % 8 == 1 */
         int *st,            /* input/output state, REQUIRE 0 <= *st <= ISSTMAX */
@@ -307,7 +307,7 @@ void ImaBlockMashI(
         int opt             /* non-zero allows some cpu-intensive code to improve output */
 )
 {
-        int ch;
+        unsigned ch;
         for (ch=0; ch<chans; ch++)
                 ImaMashChannel(ch, chans, ip, n, st+ch, obuff, opt);
 }
@@ -320,14 +320,14 @@ void ImaBlockMashI(
  *  samplesPerBlock which would go into a block of size blockAlign
  *  Yes, it is confusing.
  */
-st_size_t ImaSamplesIn(
-  st_size_t dataLen,
-  unsigned short chans,
-  unsigned short blockAlign,
-  unsigned short samplesPerBlock
+sox_size_t ImaSamplesIn(
+  sox_size_t dataLen,
+  sox_size_t chans,
+  sox_size_t blockAlign,
+  sox_size_t samplesPerBlock
 )
 {
-  st_size_t m, n;
+  sox_size_t m, n;
 
   if (samplesPerBlock) {
     n = (dataLen / blockAlign) * samplesPerBlock;
@@ -336,7 +336,7 @@ st_size_t ImaSamplesIn(
     n = 0;
     m = blockAlign;
   }
-  if (m >= (st_size_t)4*chans) {
+  if (m >= (sox_size_t)4*chans) {
     m -= 4*chans;    /* number of bytes beyond block-header */
     m /= 4*chans;    /* number of 4-byte blocks/channel beyond header */
     m = 8*m + 1;     /* samples/chan beyond header + 1 in header */
@@ -348,21 +348,21 @@ st_size_t ImaSamplesIn(
 }
 
 /*
- * st_size_t ImaBytesPerBlock(chans, samplesPerBlock)
+ * sox_size_t ImaBytesPerBlock(chans, samplesPerBlock)
  *   return minimum blocksize which would be required
  *   to encode number of chans with given samplesPerBlock
  */
-st_size_t ImaBytesPerBlock(
-  unsigned short chans,
-  unsigned short samplesPerBlock
+sox_size_t ImaBytesPerBlock(
+  sox_size_t chans,
+  sox_size_t samplesPerBlock
 )
 {
-  st_size_t n;
+  sox_size_t n;
   /* per channel, ima has blocks of len 4, the 1st has 1st sample, the others
    * up to 8 samples per block,
    * so number of later blocks is (nsamp-1 + 7)/8, total blocks/chan is
    * (nsamp-1+7)/8 + 1 = (nsamp+14)/8
    */
-  n = ((st_size_t)samplesPerBlock + 14)/8 * 4 * chans;
+  n = ((sox_size_t)samplesPerBlock + 14)/8 * 4 * chans;
   return n;
 }
