@@ -12,14 +12,11 @@
  * (at your option) any later version.
  */
 
-#include "st_i.h"
+#include "sox_i.h"
 #include "FFT.h"
 
 #include <math.h>
 
 #define WINDOWSIZE 2048
-#define FREQCOUNT (WINDOWSIZE/2+1)
-
-#ifndef min
-#define min(s1,s2) ((s1)<(s2)?(s1):(s2))
-#endif
+#define HALFWINDOW (WINDOWSIZE / 2)
+#define FREQCOUNT  (HALFWINDOW + 1)
