@@ -265,7 +265,7 @@ static void nuttall(Float *buffer, int length)
   int N1;
 
   if(buffer == NULL || length <= 0)
-    sox_fail("Illegal buffer %p or length %d to nuttall.", buffer, length);
+    sox_fail("Illegal buffer %p or length %d to nuttall.", (void *)buffer, length);
 
   /* Initial variable setups. */
   N = length;
@@ -288,7 +288,7 @@ static void hamming(Float *buffer, int length)
     int N1;
 
     if(buffer == NULL || length <= 0)
-      sox_fail("Illegal buffer %p or length %d to hamming.",buffer,length);
+      sox_fail("Illegal buffer %p or length %d to hamming.",(void *)buffer,length);
 
     N1 = length/2;
     for(j=0;j<length;j++)
@@ -314,7 +314,7 @@ static void fir_design(poly_t rate, Float *buffer, int length, double cutoff)
     double sum;
 
     if(buffer == NULL || length < 0 || cutoff < 0 || cutoff > M_PI)
-      sox_fail("Illegal buffer %p, length %d, or cutoff %f.",buffer,length,cutoff);
+      sox_fail("Illegal buffer %p, length %d, or cutoff %f.",(void *)buffer,length,cutoff);
 
     /* Use the user-option of window type */
     if (rate->win_type == 0)
@@ -353,16 +353,16 @@ static int sox_poly_start(sox_effect_t * effp)
 
     effp->outinfo.channels = effp->ininfo.channels;
 
-    rate->lcmrate = sox_lcm((sox_ssample_t)effp->ininfo.rate,
-                           (sox_ssample_t)effp->outinfo.rate);
+    rate->lcmrate = sox_lcm((sox_sample_t)effp->ininfo.rate,
+                           (sox_sample_t)effp->outinfo.rate);
 
     /* Cursory check for LCM overflow.
      * If both rates are below 65k, there should be no problem.
      * 16 bits x 16 bits = 32 bits, which we can handle.
      */
 
-    rate->inskip = rate->lcmrate / (sox_ssample_t)effp->ininfo.rate;
-    rate->outskip = rate->lcmrate / (sox_ssample_t)effp->outinfo.rate;
+    rate->inskip = rate->lcmrate / (sox_sample_t)effp->ininfo.rate;
+    rate->outskip = rate->lcmrate / (sox_sample_t)effp->outinfo.rate;
     rate->Factor = (double)rate->inskip / (double)rate->outskip;
     rate->inpipe = 0;
     {
@@ -490,7 +490,7 @@ static void update_hist(Float *hist, int hist_size, int in_size)
 
 }
 
-static int sox_poly_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssample_t *obuf,
+static int sox_poly_flow(sox_effect_t * effp, const sox_sample_t *ibuf, sox_sample_t *obuf,
                  sox_size_t *isamp, sox_size_t *osamp)
 {
   poly_t rate = (poly_t) effp->priv;
@@ -550,7 +550,7 @@ static int sox_poly_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssa
   }
 
   {
-    sox_ssample_t *q;
+    sox_sample_t *q;
     sox_size_t out_size;
     sox_size_t oskip;
     Float *out_buf;
@@ -593,7 +593,7 @@ static int sox_poly_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssa
 /*
  * Process tail of input samples.
  */
-static int sox_poly_drain(sox_effect_t * effp, sox_ssample_t *obuf, sox_size_t *osamp)
+static int sox_poly_drain(sox_effect_t * effp, sox_sample_t *obuf, sox_size_t *osamp)
 {
   sox_size_t in_size;
   /* Call "flow" with NULL input. */
