@@ -148,10 +148,10 @@ static int startread(sox_format_t * ft)
   sox_readb(ft, &byte);   /* Unused and seems always zero */
 
   sox_readdw(ft, &repgap); /* Time between repeats in usec */
-  sox_debug("Time between repeats (usec): %ld", repgap);
+  sox_debug("Time between repeats (usec): %u", repgap);
 
   sox_readdw(ft, &listlen); /* Length of samples list */
-  sox_debug("Number of bytes in samples list: %ld", listlen);
+  sox_debug("Number of bytes in samples list: %u", listlen);
 
   if (ft->signal.rate != 0 && ft->signal.rate != 8000)
     sox_report("PRC only supports 8 kHz; overriding.");
@@ -214,7 +214,7 @@ static unsigned read_cardinal(sox_format_t * ft)
   return a;
 }
 
-static sox_size_t read(sox_format_t * ft, sox_ssample_t *buf, sox_size_t samp)
+static sox_size_t read(sox_format_t * ft, sox_sample_t *buf, sox_size_t samp)
 {
   prc_t p = (prc_t)ft->priv;
 
@@ -344,7 +344,7 @@ static void write_cardinal(sox_format_t * ft, unsigned a)
   }
 }
 
-static sox_size_t write(sox_format_t * ft, const sox_ssample_t *buf, sox_size_t samp)
+static sox_size_t write(sox_format_t * ft, const sox_sample_t *buf, sox_size_t samp)
 {
   prc_t p = (prc_t)ft->priv;
   /* Psion Record seems not to be able to handle frames > 800 samples */
