@@ -106,7 +106,7 @@ static int start(sox_effect_t * effp)
 /*
  * Read, convert, return data.
  */
-static int flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssample_t *obuf UNUSED,
+static int flow(sox_effect_t * effp, const sox_sample_t *ibuf, sox_sample_t *obuf UNUSED,
                    sox_size_t *isamp, sox_size_t *osamp)
 {
   rabbit_t r = (rabbit_t) effp->priv;
@@ -163,7 +163,7 @@ static int flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssample_t *o
 /*
  * Process samples and write output.
  */
-static int drain(sox_effect_t * effp, sox_ssample_t *obuf, sox_size_t *osamp)
+static int drain(sox_effect_t * effp, sox_sample_t *obuf, sox_size_t *osamp)
 {
   rabbit_t r = (rabbit_t) effp->priv;
   static sox_size_t isamp = 0;
