@@ -69,12 +69,12 @@ static int sox_repeat_start(sox_effect_t * effp)
         return (SOX_SUCCESS);
 }
 
-static int sox_repeat_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssample_t *obuf UNUSED,
+static int sox_repeat_flow(sox_effect_t * effp, const sox_sample_t *ibuf, sox_sample_t *obuf UNUSED,
                 sox_size_t *isamp, sox_size_t *osamp)
 {
         repeat_t repeat = (repeat_t)effp->priv;
 
-        if (fwrite((char *)ibuf, sizeof(sox_ssample_t), *isamp, repeat->fp) !=
+        if (fwrite((char *)ibuf, sizeof(sox_sample_t), *isamp, repeat->fp) !=
                         *isamp) {
                 sox_fail("write error on temporary file");
                 return (SOX_EOF);
@@ -85,10 +85,10 @@ static int sox_repeat_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_s
         return (SOX_SUCCESS);
 }
 
-static int sox_repeat_drain(sox_effect_t * effp, sox_ssample_t *obuf, sox_size_t *osamp)
+static int sox_repeat_drain(sox_effect_t * effp, sox_sample_t *obuf, sox_size_t *osamp)
 {
         size_t read = 0;
-        sox_ssample_t *buf;
+        sox_sample_t *buf;
         sox_size_t samp;
         sox_size_t done;
 
@@ -100,12 +100,12 @@ static int sox_repeat_drain(sox_effect_t * effp, sox_ssample_t *obuf, sox_size_t
                 fseeko(repeat->fp, (off_t)0, SEEK_END);
                 repeat->total = ftello(repeat->fp);
 
-                if ((repeat->total % sizeof(sox_ssample_t)) != 0) {
+                if ((repeat->total % sizeof(sox_sample_t)) != 0) {
                         sox_fail("corrupted temporary file");
                         return (SOX_EOF);
                 }
 
-                repeat->total /= sizeof(sox_ssample_t);
+                repeat->total /= sizeof(sox_sample_t);
                 repeat->remaining = repeat->total;
 
                 fseeko(repeat->fp, (off_t)0, SEEK_SET);
@@ -125,7 +125,7 @@ static int sox_repeat_drain(sox_effect_t * effp, sox_ssample_t *obuf, sox_size_t
                 buf = obuf;
                 samp = repeat->remaining;
 
-                read = fread((char *)buf, sizeof(sox_ssample_t), samp,
+                read = fread((char *)buf, sizeof(sox_sample_t), samp,
                                 repeat->fp);
                 if (read != samp) {
                         perror(strerror(errno));
@@ -151,7 +151,7 @@ static int sox_repeat_drain(sox_effect_t * effp, sox_ssample_t *obuf, sox_size_t
 
                         repeat->remaining = repeat->total - samp;
 
-                        read = fread((char *)buf, sizeof(sox_ssample_t), samp,
+                        read = fread((char *)buf, sizeof(sox_sample_t), samp,
                                         repeat->fp);
                         if (read != samp) {
                                 perror(strerror(errno));
@@ -167,7 +167,7 @@ static int sox_repeat_drain(sox_effect_t * effp, sox_ssample_t *obuf, sox_size_t
                 *osamp = done;
         }
         else {
-                read = fread((char *)obuf, sizeof(sox_ssample_t), *osamp,
+                read = fread((char *)obuf, sizeof(sox_sample_t), *osamp,
                                 repeat->fp);
                 if (read != *osamp) {
                         perror(strerror(errno));
