@@ -29,16 +29,50 @@
 #include <ctype.h>
 #include <sndfile.h>
 
+#define LOG_MAX 2048 /* As per the SFC_GET_LOG_INFO example */
+
+#ifndef HACKED_LSF
+#define sf_stop(x)
+#endif
+
 /* Private data for sndfile files */
 typedef struct sndfile
 {
   SNDFILE *sf_file;
   SF_INFO *sf_info;
+  char * log_buffer;
+  char const * log_buffer_ptr;
 } *sndfile_t;
 
 assert_static(sizeof(struct sndfile) <= SOX_MAX_FILE_PRIVSIZE, 
               /* else */ sndfile_PRIVSIZE_too_big);
 
+/*
+ * Drain LSF's wonderful log buffer
+ */
+static void drain_log_buffer(sox_format_t * ft)
+{
+  sndfile_t sf = (sndfile_t)ft->priv;
+
+  sf_command(sf->sf_file, SFC_GET_LOG_INFO, sf->log_buffer, LOG_MAX);
+  while (*sf->log_buffer_ptr) {
+    static char const warning_prefix[] = "*** Warning : ";
+    char const * end = strchr(sf->log_buffer_ptr, '\n');
+    if (!end)
+      end = strchr(sf->log_buffer_ptr, '\0');
+    if (!strncmp(sf->log_buffer_ptr, warning_prefix, strlen(warning_prefix))) {
+      sf->log_buffer_ptr += strlen(warning_prefix);
+      sox_warn("`%s': %.*s",
+          ft->filename, end - sf->log_buffer_ptr, sf->log_buffer_ptr);
+    } else
+      sox_debug("`%s': %.*s",
+          ft->filename, end - sf->log_buffer_ptr, sf->log_buffer_ptr);
+    sf->log_buffer_ptr = end;
+    if (*sf->log_buffer_ptr == '\n')
+      ++sf->log_buffer_ptr;
+  }
+}
+
 /* Get sample encoding and size from libsndfile subtype; return value
    is encoding if conversion was made, or SOX_ENCODING_UNKNOWN for
    invalid input. If the libsndfile subtype can't be represented in
@@ -77,13 +111,17 @@ static sox_encoding_t sox_encoding_and_size(int format, int *size)
     *size = SOX_SIZE_8BIT;
     return SOX_ENCODING_ALAW;
   case SF_FORMAT_IMA_ADPCM:
+    *size = SOX_SIZE_16BIT;
     return SOX_ENCODING_IMA_ADPCM;
   case SF_FORMAT_MS_ADPCM:
+    *size = SOX_SIZE_16BIT;
     return SOX_ENCODING_MS_ADPCM;
   case SF_FORMAT_GSM610:
+    *size = SOX_SIZE_16BIT;
     return SOX_ENCODING_GSM;
   case SF_FORMAT_VOX_ADPCM:
-    return SOX_ENCODING_ADPCM;
+    *size = SOX_SIZE_16BIT;
+    return SOX_ENCODING_OKI_ADPCM;
 
   /* For encodings we can't represent, have a sensible default */
   case SF_FORMAT_G721_32:
@@ -105,88 +143,44 @@ static sox_encoding_t sox_encoding_and_size(int format, int *size)
   return SOX_ENCODING_UNKNOWN;
 }
 
-/*
- * Open file in sndfile.
- */
-static int startread(sox_format_t * ft)
-{
-  sndfile_t sf = (sndfile_t)ft->priv;
-
-  sf->sf_info = (SF_INFO *)xcalloc(1, sizeof(SF_INFO));
-  /* We'd like to use sf_open_fd, but auto file typing has already
-     invoked stdio buffering. */
-  /* FIXME: If format parameters are set, assume file is raw. */
-  if ((sf->sf_file = sf_open(ft->filename, SFM_READ, sf->sf_info)) == NULL) {
-    sox_fail("sndfile cannot open file for reading: %s", sf_strerror(sf->sf_file));
-    free(sf->sf_file);
-    return SOX_EOF;
-  }
-
-  /* Copy format info */
-  ft->signal.rate = sf->sf_info->samplerate;
-  ft->signal.encoding = sox_encoding_and_size(sf->sf_info->format, &ft->signal.size);
-  ft->signal.channels = sf->sf_info->channels;
-  ft->length = sf->sf_info->frames * sf->sf_info->channels;
-
-  return SOX_SUCCESS;
-}
-
-/*
- * Read up to len samples of type sox_sample_t from file into buf[].
- * Return number of samples read.
- */
-static sox_size_t read(sox_format_t * ft, sox_ssample_t *buf, sox_size_t len)
-{
-  sndfile_t sf = (sndfile_t)ft->priv;
-
-  /* FIXME: We assume int == sox_sample_t here */
-  return (sox_size_t)sf_read_int(sf->sf_file, (int *)buf, (sf_count_t)len);
-}
-
-/*
- * Close file for libsndfile (this doesn't close the file handle)
- */
-static int stopread(sox_format_t * ft)
-{
-  sndfile_t sf = (sndfile_t)ft->priv;
-  sf_close(sf->sf_file);
-  return SOX_SUCCESS;
-}
-
 static struct {
   const char *ext;
-  unsigned len;
   int format;
 } format_map[] =
 {
-  { "aif",	3, SF_FORMAT_AIFF },
-  { "wav",	0, SF_FORMAT_WAV },
-  { "au",	0, SF_FORMAT_AU },
-  { "snd",	0, SF_FORMAT_AU },
+  { "aif",	SF_FORMAT_AIFF },
+  { "aiff",	SF_FORMAT_AIFF },
+  { "wav",	SF_FORMAT_WAV },
+  { "au",	SF_FORMAT_AU },
+  { "snd",	SF_FORMAT_AU },
 #ifdef HAVE_SNDFILE_1_0_12
-  { "caf",	0, SF_FORMAT_CAF },
-  { "flac",	0, SF_FORMAT_FLAC },
+  { "caf",	SF_FORMAT_CAF },
+  { "flac",	SF_FORMAT_FLAC },
 #endif
-  { "svx",	0, SF_FORMAT_SVX },
-  { "8svx",     0, SF_FORMAT_SVX },
-  { "paf",	0, SF_ENDIAN_BIG | SF_FORMAT_PAF },
-  { "fap",	0, SF_ENDIAN_LITTLE | SF_FORMAT_PAF },
-  { "gsm",	0, SF_FORMAT_RAW | SF_FORMAT_GSM610 },
-  { "nist", 	0, SF_FORMAT_NIST },
-  { "sph",      0, SF_FORMAT_NIST },
-  { "ircam",	0, SF_FORMAT_IRCAM },
-  { "sf",	0, SF_FORMAT_IRCAM },
-  { "voc",	0, SF_FORMAT_VOC },
-  { "w64", 	0, SF_FORMAT_W64 },
-  { "raw",	0, SF_FORMAT_RAW },
-  { "mat4", 	0, SF_FORMAT_MAT4 },
-  { "mat5", 	0, SF_FORMAT_MAT5 },
-  { "mat",	0, SF_FORMAT_MAT4 },
-  { "pvf",	0, SF_FORMAT_PVF },
-  { "sds",	0, SF_FORMAT_SDS },
-  { "sd2",	0, SF_FORMAT_SD2 },
-  { "vox",	0, SF_FORMAT_RAW | SF_FORMAT_VOX_ADPCM },
-  { "xi",	0, SF_FORMAT_XI }
+#ifdef HAVE_SNDFILE_1_0_18
+  { "wve",	SF_FORMAT_WVE },
+  { "ogg",	SF_FORMAT_OGG },
+#endif
+  { "svx",	SF_FORMAT_SVX },
+  { "8svx",     SF_FORMAT_SVX },
+  { "paf",	SF_ENDIAN_BIG | SF_FORMAT_PAF },
+  { "fap",	SF_ENDIAN_LITTLE | SF_FORMAT_PAF },
+  { "gsm",	SF_FORMAT_RAW | SF_FORMAT_GSM610 },
+  { "nist", 	SF_FORMAT_NIST },
+  { "sph",      SF_FORMAT_NIST },
+  { "ircam",	SF_FORMAT_IRCAM },
+  { "sf",	SF_FORMAT_IRCAM },
+  { "voc",	SF_FORMAT_VOC },
+  { "w64", 	SF_FORMAT_W64 },
+  { "raw",	SF_FORMAT_RAW },
+  { "mat4", 	SF_FORMAT_MAT4 },
+  { "mat5", 	SF_FORMAT_MAT5 },
+  { "mat",	SF_FORMAT_MAT4 },
+  { "pvf",	SF_FORMAT_PVF },
+  { "sds",	SF_FORMAT_SDS },
+  { "sd2",	SF_FORMAT_SD2 },
+  { "vox",	SF_FORMAT_RAW | SF_FORMAT_VOX_ADPCM },
+  { "xi",	SF_FORMAT_XI }
 };
 
 /* Convert file name or type to libsndfile format */
@@ -198,7 +192,7 @@ static int name_to_format(const char *name)
 
   if ((cptr = strrchr(name, '.')) != NULL) {
     strncpy(buffer, cptr + 1, FILE_TYPE_BUFLEN);
-    buffer[FILE_TYPE_BUFLEN] = 0;
+    buffer[FILE_TYPE_BUFLEN] = '\0';
   
     for (k = 0; buffer[k]; k++)
       buffer[k] = tolower((buffer[k]));
@@ -206,9 +200,7 @@ static int name_to_format(const char *name)
     strncpy(buffer, name, FILE_TYPE_BUFLEN);
   
   for (k = 0; k < (int)(sizeof(format_map) / sizeof(format_map [0])); k++) {
-    if (format_map[k].len > 0 && strncmp(name, format_map[k].ext, format_map[k].len) == 0)
-      return format_map[k].format;
-    else if (strcmp(buffer, format_map[k].ext) == 0)
+    if (strcmp(buffer, format_map[k].ext) == 0)
       return format_map[k].format;
   }
 
@@ -270,27 +262,98 @@ static int sndfile_format(sox_encoding_t encoding, int size)
   }
 }
 
-static int startwrite(sox_format_t * ft)
+static void start(sox_format_t * ft)
 {
   sndfile_t sf = (sndfile_t)ft->priv;
   int subtype = sndfile_format(ft->signal.encoding, ft->signal.size);
-  sf->sf_info = (SF_INFO *)xmalloc(sizeof(SF_INFO));
+  sf->log_buffer_ptr = sf->log_buffer = xmalloc(LOG_MAX);
+  sf->sf_info = (SF_INFO *)xcalloc(1, sizeof(SF_INFO));
 
   /* Copy format info */
-  if (strcmp(ft->filetype, "sndfile") == 0)
-    sf->sf_info->format = name_to_format(ft->filename) | subtype;
-  else
-    sf->sf_info->format = name_to_format(ft->filetype) | subtype;
+  if (subtype) {
+    if (strcmp(ft->filetype, "sndfile") == 0)
+      sf->sf_info->format = name_to_format(ft->filename) | subtype;
+    else
+      sf->sf_info->format = name_to_format(ft->filetype) | subtype;
+  }
   sf->sf_info->samplerate = ft->signal.rate;
   sf->sf_info->channels = ft->signal.channels;
-  sf->sf_info->frames = ft->length / ft->signal.channels;
+  if (ft->signal.channels)
+    sf->sf_info->frames = ft->length / ft->signal.channels;
+}
 
+/*
+ * Open file in sndfile.
+ */
+static int startread(sox_format_t * ft)
+{
+  sndfile_t sf = (sndfile_t)ft->priv;
+
+  start(ft);
+
+  /* We'd like to use sf_open_fd, but auto file typing has already
+     invoked stdio buffering. */
+  sf->sf_file = sf_open(ft->filename, SFM_READ, sf->sf_info);
+  drain_log_buffer(ft);
+
+  if (sf->sf_file == NULL) {
+    memset(ft->sox_errstr, 0, sizeof(ft->sox_errstr));
+    strncpy(ft->sox_errstr, sf_strerror(sf->sf_file), sizeof(ft->sox_errstr)-1);
+    free(sf->sf_file);
+    return SOX_EOF;
+  }
+
+  /* Copy format info */
+  ft->signal.encoding = sox_encoding_and_size(sf->sf_info->format, &ft->signal.size);
+  ft->signal.channels = sf->sf_info->channels;
+  ft->length = sf->sf_info->frames * sf->sf_info->channels;
+
+  /* FIXME: it would be better if LSF were able to do this */
+  if ((sf->sf_info->format & SF_FORMAT_TYPEMASK) == SF_FORMAT_RAW) {
+    if (ft->signal.rate == 0) {
+      sox_warn("'%s': sample rate not specified; trying 8kHz", ft->filename);
+      ft->signal.rate = 8000;
+    }
+  }
+  else ft->signal.rate = sf->sf_info->samplerate;
+
+  return SOX_SUCCESS;
+}
+
+/*
+ * Read up to len samples of type sox_sample_t from file into buf[].
+ * Return number of samples read.
+ */
+static sox_size_t read(sox_format_t * ft, sox_sample_t *buf, sox_size_t len)
+{
+  sndfile_t sf = (sndfile_t)ft->priv;
+
+  /* FIXME: We assume int == sox_sample_t here */
+  return (sox_size_t)sf_read_int(sf->sf_file, (int *)buf, (sf_count_t)len);
+}
+
+/*
+ * Close file for libsndfile (this doesn't close the file handle)
+ */
+static int stopread(sox_format_t * ft)
+{
+  sndfile_t sf = (sndfile_t)ft->priv;
+  sf_stop(sf->sf_file);
+  drain_log_buffer(ft);
+  sf_close(sf->sf_file);
+  return SOX_SUCCESS;
+}
+
+static int startwrite(sox_format_t * ft)
+{
+  sndfile_t sf = (sndfile_t)ft->priv;
+
+  start(ft);
   /* If output format is invalid, try to find a sensible default */
   if (!sf_format_check(sf->sf_info)) {
     SF_FORMAT_INFO format_info;
     int i, count;
 
-    sox_warn("cannot use desired output encoding, choosing default");
     sf_command(sf->sf_file, SFC_GET_SIMPLE_FORMAT_COUNT, &count, sizeof(int));
     for (i = 0; i < count; i++) {
       format_info.format = i;
@@ -307,10 +370,17 @@ static int startwrite(sox_format_t * ft)
       sox_fail("cannot find a usable output encoding");
       return SOX_EOF;
     }
+    if ((sf->sf_info->format & SF_FORMAT_TYPEMASK) != SF_FORMAT_RAW)
+      sox_warn("cannot use desired output encoding, choosing default");
   }
 
-  if ((sf->sf_file = sf_open(ft->filename, SFM_WRITE, sf->sf_info)) == NULL) {
-    sox_fail("sndfile cannot open file for writing: %s", sf_strerror(sf->sf_file));
+  sf->sf_file = sf_open(ft->filename, SFM_WRITE, sf->sf_info);
+  drain_log_buffer(ft);
+
+  if (sf->sf_file == NULL) {
+    memset(ft->sox_errstr, 0, sizeof(ft->sox_errstr));
+    strncpy(ft->sox_errstr, sf_strerror(sf->sf_file), sizeof(ft->sox_errstr)-1);
+    free(sf->sf_file);
     return SOX_EOF;
   }
 
@@ -321,7 +391,7 @@ static int startwrite(sox_format_t * ft)
  * Write len samples of type sox_sample_t from buf[] to file.
  * Return number of samples written.
  */
-static sox_size_t write(sox_format_t * ft, const sox_ssample_t *buf, sox_size_t len)
+static sox_size_t write(sox_format_t * ft, const sox_sample_t *buf, sox_size_t len)
 {
   sndfile_t sf = (sndfile_t)ft->priv;
 
@@ -335,6 +405,8 @@ static sox_size_t write(sox_format_t * ft, const sox_ssample_t *buf, sox_size_t
 static int stopwrite(sox_format_t * ft)
 {
   sndfile_t sf = (sndfile_t)ft->priv;
+  sf_stop(sf->sf_file);
+  drain_log_buffer(ft);
   sf_close(sf->sf_file);
   return SOX_SUCCESS;
 }
