@@ -17,12 +17,13 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library. If not, write to the Free Software
+ * along with this program. If not, write to the Free Software
  * Foundation, Fifth Floor, 51 Franklin Street, Boston, MA 02111-1301,
  * USA.
  */
 
 #include "sox_i.h"
+#include "getopt.h"
 
 #include <ctype.h>
 #include <errno.h>
@@ -51,12 +52,6 @@
   #include <unistd.h>
 #endif
 
-#ifdef HAVE_GETOPT_LONG
-  #include <getopt.h>
-#else
-  #include "getopt.h"
-#endif
-
 #ifdef HAVE_GETTIMEOFDAY
   #define TIME_FRAC 1e6
 #else
@@ -126,6 +121,8 @@ static size_t input_count = 0;
 #define MAX_USER_EFF (SOX_MAX_EFFECTS - 4)
 static sox_effect_t user_efftab[MAX_USER_EFF];
 static unsigned nuser_effects;
+static sox_effects_chain_t ofile_effects_chain;
+
 
 
 /* Flowing */
@@ -245,7 +242,7 @@ static void usage(char const * message)
 "-X, --reverse-bits  bit-order of data",
 "-B/-L           force endianness to big/little",
 "-s/-u/-U/-A/    sample encoding: signed/unsigned/u-law/A-law",
-"  -a/-i/-g/-f   ADPCM/IMA_ADPCM/GSM/floating point",
+"  -a/-i/-g/-f   ADPCM/IMA ADPCM/GSM/floating point",
 "-1/-2/-3/-4/-8  sample size in bytes",
 "-v, --volume FACTOR  volume input file volume adjustment factor (real number)",
 ""};
@@ -323,7 +320,6 @@ static void cleanup(void)
   for (i = 0; i < input_count; i++) {
     if (files[i]->ft) {
       sox_close(files[i]->ft);
-      free(files[i]->ft);
     }
     free(files[i]);
   }
@@ -341,7 +337,6 @@ static void cleanup(void)
 
       /* Assumption: we can unlink a file before sox_closing it. */
       sox_close(ofile->ft);
-      free(ofile->ft);
     }
     free(ofile);
   }
@@ -370,27 +365,43 @@ static file_t new_file(void)
 
 static void set_device(file_t f, sox_bool recording UNUSED)
 {
-#ifdef HAVE_LIBAO
-  if (!recording) {
-    f->filetype = "ao";
+#if defined(HAVE_ALSA)
+  if (sox_find_format("alsa", sox_false))
+  {
+    f->filetype = "alsa";
     f->filename = xstrdup("default");
     return;
   }
 #endif
-#if defined(HAVE_ALSA)
-  f->filetype = "alsa";
-  f->filename = xstrdup("default");
-#elif defined(HAVE_SYS_SOUNDCARD_H) || defined(HAVE_MACHINE_SOUNDCARD_H)
-  f->filetype = "ossdsp";
-  f->filename = xstrdup("/dev/dsp");
-#elif defined(HAVE_SYS_AUDIOIO_H) || defined(HAVE_SUN_AUDIOIO_H)
-  char *device = getenv("AUDIODEV");
-  f->filetype = "sunau";
-  f->filename = xstrdup(device ? device : "/dev/audio");
-#else
+#if defined(HAVE_SYS_SOUNDCARD_H) || defined(HAVE_MACHINE_SOUNDCARD_H)
+  if (sox_find_format("ossdsp", sox_false))
+  {
+    f->filetype = "ossdsp";
+    f->filename = xstrdup("/dev/dsp");
+    return;
+  }
+#endif
+#if defined(HAVE_SYS_AUDIOIO_H) || defined(HAVE_SUN_AUDIOIO_H)
+  if (sox_find_format("sunau", sox_false))
+  {
+    char *device = getenv("AUDIODEV");
+    f->filetype = "sunau";
+    f->filename = xstrdup(device ? device : "/dev/audio");
+    return;
+  }
+#endif
+#ifdef HAVE_LIBAO
+  if (!recording) {
+    if (sox_find_format("ao", sox_false))
+    {
+        f->filetype = "ao";
+        f->filename = xstrdup("default");
+        return;
+    }
+  }
+#endif
   sox_fail("Sorry, there is no default audio device configured");
   exit(1);
-#endif
 }
 
 static void set_replay_gain(char const * comment, file_t f)
@@ -568,8 +579,8 @@ static void parse_options_and_filenames(int argc, char **argv)
     file_count++;
 
     f = new_file();
-    set_device(f, sox_true);
     files[0] = f;
+    set_device(f, sox_true);
   }
 }
 
@@ -706,13 +717,9 @@ int main(int argc, char **argv)
   if (combine_method == sox_sequence) do {
     if (ofile->ft)
       sox_close(ofile->ft);
-    free(ofile->ft);
   } while (process() != SOX_EOF && !user_abort && current_input < input_count);
   else process();
 
-  while (nuser_effects--)
-    user_efftab[nuser_effects].handler.kill(&user_efftab[nuser_effects]);
-
   for (i = 0; i < file_count; ++i)
     if (files[i]->ft->clips != 0)
       sox_warn(i < input_count?"%s: input clipped %u samples" :
@@ -1145,16 +1152,33 @@ static sox_bool can_segue(sox_size_t i)
     files[i]->ft->signal.rate     == files[i - 1]->ft->signal.rate;
 }
 
-static sox_size_t sox_read_wide(sox_format_t * ft, sox_ssample_t * buf, sox_size_t max)
+static void display_error(sox_format_t * ft)
+{
+  static char const * const sox_strerror[] = {
+    "Invalid Audio Header",
+    "Unsupported data format",
+    "Unsupported rate for format",
+    "Can't alloc memory",
+    "Operation not permitted",
+    "Operation not supported",
+    "Invalid argument",
+    "Unsupported file format",
+  };
+  sox_fail("%s: %s (%s)", ft->filename, ft->sox_errstr,
+      ft->sox_errno < SOX_EHDR?
+      strerror(ft->sox_errno) : sox_strerror[ft->sox_errno - SOX_EHDR]);
+}
+
+static sox_size_t sox_read_wide(sox_format_t * ft, sox_sample_t * buf, sox_size_t max)
 {
   sox_size_t len = max / combiner.channels;
   len = sox_read(ft, buf, len * ft->signal.channels) / ft->signal.channels;
   if (!len && ft->sox_errno)
-    sox_fail("%s: %s (%s)", ft->filename, ft->sox_errstr, strerror(ft->sox_errno));
+    display_error(ft);
   return len;
 }
 
-static void balance_input(sox_ssample_t * buf, sox_size_t ws, file_t f)
+static void balance_input(sox_sample_t * buf, sox_size_t ws, file_t f)
 {
   sox_size_t s = ws * f->ft->signal.channels;
 
@@ -1167,7 +1191,7 @@ static void balance_input(sox_ssample_t * buf, sox_size_t ws, file_t f)
 
 typedef struct input_combiner
 {
-  sox_ssample_t *ibuf[MAX_INPUT_FILES];
+  sox_sample_t *ibuf[MAX_INPUT_FILES];
 } * input_combiner_t;
 
 assert_static(sizeof(struct input_combiner) <= SOX_MAX_EFFECT_PRIVSIZE,
@@ -1183,7 +1207,7 @@ static int combiner_start(sox_effect_t *effp)
   else {
     ws = 0;
     for (i = 0; i < input_count; i++) {
-      z->ibuf[i] = (sox_ssample_t *)xmalloc(sox_globals.bufsiz * sizeof(sox_ssample_t));
+      z->ibuf[i] = (sox_sample_t *)xmalloc(sox_globals.bufsiz * sizeof(sox_sample_t));
       progress_to_file(files[i]);
       ws = max(ws, input_wide_samples);
     }
@@ -1192,7 +1216,7 @@ static int combiner_start(sox_effect_t *effp)
   return SOX_SUCCESS;
 }
 
-static int combiner_drain(sox_effect_t *effp, sox_ssample_t * obuf, sox_size_t * osamp)
+static int combiner_drain(sox_effect_t *effp, sox_sample_t * obuf, sox_size_t * osamp)
 {
   input_combiner_t z = (input_combiner_t) effp->priv;
   sox_size_t ws, s, i;
@@ -1213,7 +1237,7 @@ static int combiner_drain(sox_effect_t *effp, sox_ssample_t * obuf, sox_size_t *
     balance_input(obuf, olen, files[current_input]);
     break;
   } else {
-    sox_ssample_t * p = obuf;
+    sox_sample_t * p = obuf;
     for (i = 0; i < input_count; ++i) {
       ilen[i] = sox_read_wide(files[i]->ft, z->ibuf[i], *osamp);
       balance_input(z->ibuf[i], ilen[i], files[i]);
@@ -1264,8 +1288,8 @@ static sox_effect_handler_t const * input_combiner_effect_fn(void)
   return &handler;
 }
 
-static int output_flow(sox_effect_t *effp UNUSED, sox_ssample_t const * ibuf,
-    sox_ssample_t * obuf UNUSED, sox_size_t * isamp, sox_size_t * osamp)
+static int output_flow(sox_effect_t *effp UNUSED, sox_sample_t const * ibuf,
+    sox_sample_t * obuf UNUSED, sox_size_t * isamp, sox_size_t * osamp)
 {
   size_t len;
   for (*osamp = *isamp; *osamp; ibuf += len, *osamp -= len) {
@@ -1289,7 +1313,7 @@ static sox_effect_handler_t const * output_effect_fn(void)
   return &handler;
 }
 
-static void add_auto_effect(char const * name, sox_signalinfo_t * signal)
+static void add_auto_effect(sox_effects_chain_t * chain, char const * name, sox_signalinfo_t * signal)
 {
   sox_effect_t eff;
 
@@ -1298,12 +1322,12 @@ static void add_auto_effect(char const * name, sox_signalinfo_t * signal)
   eff.handler.getopts(&eff, 0, NULL);          /* Set up with default opts */
 
   /* But could fail here */
-  if (sox_add_effect(&eff, signal, &ofile->ft->signal) != SOX_SUCCESS)
+  if (sox_add_effect(chain, &eff, signal, &ofile->ft->signal) != SOX_SUCCESS)
     exit(2);
 }
 
 /* If needed effects are not given, auto-add at (performance) optimal point. */
-static void add_effects(void)
+static void add_effects(sox_effects_chain_t * chain)
 {
   sox_signalinfo_t signal = combiner;
   unsigned i, min_chan = 0, min_rate = 0;
@@ -1318,36 +1342,36 @@ static void add_effects(void)
   }
   /* 1st `effect' in the chain is the input combiner */
   sox_create_effect(&eff, input_combiner_effect_fn());
-  sox_add_effect(&eff, &signal, &ofile->ft->signal);
+  sox_add_effect(chain, &eff, &signal, &ofile->ft->signal);
 
   /* Add auto effects if appropriate; add user specified effects */
   for (i = 0; i <= nuser_effects; i++) {
     /* If reducing channels, it's faster to do so before all other effects: */
     if (signal.channels > ofile->ft->signal.channels && i >= min_chan)
-      add_auto_effect("mixer", &signal);
+      add_auto_effect(chain, "mixer", &signal);
 
     /* If reducing rate, it's faster to do so before all other effects
      * (except reducing channels): */
     if (signal.rate > ofile->ft->signal.rate && i >= min_rate)
-      add_auto_effect("resample", &signal);
+      add_auto_effect(chain, "resample", &signal);
 
     if (i < nuser_effects)
-      if (sox_add_effect(&user_efftab[i], &signal, &ofile->ft->signal) != SOX_SUCCESS)
+      if (sox_add_effect(chain, &user_efftab[i], &signal, &ofile->ft->signal) != SOX_SUCCESS)
         exit(2);
   }
   /* Add auto effects if still needed at this point */
   if (signal.rate != ofile->ft->signal.rate)
-    add_auto_effect("resample", &signal);  /* Must be up-sampling */
+    add_auto_effect(chain, "resample", &signal);  /* Must be up-sampling */
   if (signal.channels != ofile->ft->signal.channels)
-    add_auto_effect("mixer", &signal);     /* Must be increasing channels */
+    add_auto_effect(chain, "mixer", &signal);     /* Must be increasing channels */
 
   /* Last `effect' in the chain is the output file */
   sox_create_effect(&eff, output_effect_fn());
-  if (sox_add_effect(&eff, &signal, &ofile->ft->signal) != SOX_SUCCESS)
+  if (sox_add_effect(chain, &eff, &signal, &ofile->ft->signal) != SOX_SUCCESS)
     exit(2);
 
-  for (i = 0; i < sox_neffects; ++i) {
-    sox_effect_t * effp = &sox_effects[i][0];
+  for (i = 0; i < chain->length; ++i) {
+    sox_effect_t const * effp = &chain->effects[i][0];
     sox_report("effects chain: %-10s %gHz %u channels %u bits %s",
         effp->handler.name, effp->ininfo.rate, effp->ininfo.channels, effp->ininfo.size * 8,
         (effp->handler.flags & SOX_EFF_MCHAN)? "(multi)" : "");
@@ -1366,16 +1390,16 @@ static void optimize_trim(void)
    * This hack is a huge time savings when trimming
    * gigs of audio data into managable chunks
    */ 
-  if (input_count == 1 && sox_neffects > 1 && strcmp(sox_effects[1][0].handler.name, "trim") == 0) {
+  if (input_count == 1 && ofile_effects_chain.length > 1 && strcmp(ofile_effects_chain.effects[1][0].handler.name, "trim") == 0) {
     if ((files[0]->ft->handler->flags & SOX_FILE_SEEK) && files[0]->ft->seekable){
-      sox_size_t offset = sox_trim_get_start(&sox_effects[1][0]);
-      if (sox_seek(files[0]->ft, offset, SOX_SEEK_SET) != SOX_EOF) { 
+      sox_size_t offset = sox_trim_get_start(&ofile_effects_chain.effects[1][0]);
+      if (offset && sox_seek(files[0]->ft, offset, SOX_SEEK_SET) == SOX_SUCCESS) { 
         read_wide_samples = offset / files[0]->ft->signal.channels;
         /* Assuming a failed seek stayed where it was.  If the 
          * seek worked then reset the start location of 
          * trim so that it thinks user didn't request a skip.
          */ 
-        sox_trim_clear_start(&sox_effects[1][0]);
+        sox_trim_clear_start(&ofile_effects_chain.effects[1][0]);
       }    
     }        
   }    
@@ -1437,16 +1461,6 @@ static int update_status(sox_bool all_done)
   return user_abort? SOX_EOF : SOX_SUCCESS;
 }
 
-static void sox_stop_effects(void)
-{
-  sox_size_t e, clips;
-
-  for (e = 0; e < sox_neffects; ++e)
-    if ((clips = sox_stop_effect(e)) != 0)
-      sox_warn("%s clipped %u samples; decrease volume?",
-          sox_effects[e][0].handler.name, clips);
-}
-
 /*
  * Process:   Input(s) -> Balancing -> Combiner -> Effects -> Output
  */
@@ -1477,9 +1491,9 @@ static int process(void) {
       max_rate = max(max_rate, files[i]->ft->signal.rate);
       known_length = known_length && files[i]->ft->length != 0;
       if (combine_method == sox_concatenate)
-        olen += files[i]->ft->length;
+        olen += files[i]->ft->length / files[i]->ft->signal.channels;
       else
-        olen = max(olen, files[i]->ft->length);
+        olen = max(olen, files[i]->ft->length / files[i]->ft->signal.channels);
     }
     if (min_rate != max_rate)
       sox_fail("Input files must have the same sample-rate");
@@ -1515,9 +1529,10 @@ static int process(void) {
   if (!known_length)
     olen = 0;
 
-  open_output_file(olen);
+  open_output_file(olen * ofile->signal.channels * ofile->signal.rate / combiner.rate + .5);
 
-  add_effects();
+  ofile_effects_chain.global_info = sox_effects_globals;
+  add_effects(&ofile_effects_chain);
 
   optimize_trim();
 
@@ -1525,10 +1540,9 @@ static int process(void) {
   /* FIXME: For SIGTERM at least we really should guarantee to stop quickly */
   signal(SIGTERM, sigint); /* Stop gracefully even in extremis */
   
-  flowstatus = sox_flow_effects(update_status);
+  flowstatus = sox_flow_effects(&ofile_effects_chain, update_status);
 
-  sox_stop_effects();
-  sox_delete_effects();
+  sox_delete_effects(&ofile_effects_chain);
   return flowstatus;
 }
 
@@ -1538,7 +1552,7 @@ static sox_size_t total_clips(void)
   sox_size_t clips = 0;
   for (i = 0; i < file_count; ++i)
     clips += files[i]->ft->clips + files[i]->volume_clips;
-  return clips + mixing_clips + sox_effects_clips();
+  return clips + mixing_clips + sox_effects_clips(&ofile_effects_chain);
 }
 
 static char const * sigfigs3(sox_size_t number)
