@@ -92,7 +92,7 @@ static int sox_trim_start(sox_effect_t * effp)
  * Place in buf[].
  * Return number of samples read.
  */
-static int sox_trim_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssample_t *obuf, 
+static int sox_trim_flow(sox_effect_t * effp, const sox_sample_t *ibuf, sox_sample_t *obuf, 
                  sox_size_t *isamp, sox_size_t *osamp)
 {
     int result = SOX_SUCCESS;
@@ -110,7 +110,7 @@ static int sox_trim_flow(sox_effect_t * effp, const sox_ssample_t *ibuf, sox_ssa
      */
     if (!trim->trimmed) {
         if ((trim->index+done) <= trim->start) {
-            /* If we haven't read more then "start" samples, return that
+            /* If we haven't read more than "start" samples, return that
              * we've read all this buffer without outputing anything
              */
             *osamp = 0;
