@@ -17,7 +17,7 @@
  * the consequences of using this software.
  *
  * TODO: When reading in comments, it doesn't understand how to read
- * more then one comment and doesn't know how to parse KEY=value.
+ * more than one comment and doesn't know how to parse KEY=value.
  */
 
 #include "sox_i.h"
@@ -101,7 +101,7 @@ static int startread(sox_format_t * ft)
                 (size_t (*)(void *, size_t, size_t, void *))  fread,
                 (int (*)(void *, ogg_int64_t, int))           _fseeko64_wrap,
                 (int (*)(void *))                             myclose,
-                (long (*)(void *))                            ftello
+                (long (*)(void *))                            ftell
         };
 
         /* Allocate space for decoding structure */
@@ -210,12 +210,12 @@ static int refill_buffer (vorbis_t vb)
  * Return number of samples read.
  */
 
-static sox_size_t read(sox_format_t * ft, sox_ssample_t *buf, sox_size_t len)
+static sox_size_t read(sox_format_t * ft, sox_sample_t *buf, sox_size_t len)
 {
         vorbis_t vb = (vorbis_t) ft->priv;
         sox_size_t i;
         int ret;
-        sox_ssample_t l;
+        sox_sample_t l;
 
 
         for(i = 0; i < len; i++) {
@@ -356,7 +356,7 @@ static int startwrite(sox_format_t * ft)
         return(SOX_SUCCESS);
 }
 
-static sox_size_t write(sox_format_t * ft, const sox_ssample_t *buf, sox_size_t len)
+static sox_size_t write(sox_format_t * ft, const sox_sample_t *buf, sox_size_t len)
 {
         vorbis_t vb = (vorbis_t) ft->priv;
         vorbis_enc_t *ve = vb->vorbis_enc_data;
