@@ -12,7 +12,7 @@
 
 int sox_vox_start(sox_format_t * ft);
 int sox_ima_start(sox_format_t * ft);
-sox_size_t sox_vox_read(sox_format_t * ft, sox_ssample_t *buffer, sox_size_t len);
+sox_size_t sox_vox_read(sox_format_t * ft, sox_sample_t *buffer, sox_size_t len);
 int sox_vox_stopread(sox_format_t * ft);
-sox_size_t sox_vox_write(sox_format_t * ft, const sox_ssample_t *buffer, sox_size_t length);
+sox_size_t sox_vox_write(sox_format_t * ft, const sox_sample_t *buffer, sox_size_t length);
 int sox_vox_stopwrite(sox_format_t * ft);
