@@ -221,7 +221,7 @@ static void wavgsmdestroy(sox_format_t * ft)
     free(wav->gsmsample);
 }
 
-static sox_size_t wavgsmread(sox_format_t * ft, sox_ssample_t *buf, sox_size_t len)
+static sox_size_t wavgsmread(sox_format_t * ft, sox_sample_t *buf, sox_size_t len)
 {
     wav_t       wav = (wav_t) ft->priv;
     size_t done=0;
@@ -289,7 +289,7 @@ static int wavgsmflush(sox_format_t * ft)
     return (SOX_SUCCESS);
 }
 
-static sox_size_t wavgsmwrite(sox_format_t * ft, const sox_ssample_t *buf, sox_size_t len)
+static sox_size_t wavgsmwrite(sox_format_t * ft, const sox_sample_t *buf, sox_size_t len)
 {
     wav_t wav = (wav_t) ft->priv;
     size_t done = 0;
@@ -1001,7 +1001,7 @@ static int sox_wavstartread(sox_format_t * ft)
  * Return number of samples read.
  */
 
-static sox_size_t sox_wavread(sox_format_t * ft, sox_ssample_t *buf, sox_size_t len) 
+static sox_size_t sox_wavread(sox_format_t * ft, sox_sample_t *buf, sox_size_t len) 
 {
         wav_t   wav = (wav_t) ft->priv;
         sox_size_t done;
@@ -1426,7 +1426,7 @@ static int wavwritehdr(sox_format_t * ft, int second_header)
     if (wFormatTag == WAVE_FORMAT_GSM610)
         dwDataLength = (dwDataLength+1) & ~1u; /*round up to even */
 
-    if ((wFormatTag == WAVE_FORMAT_PCM && wBitsPerSample > 16) || wChannels > 2)
+    if ((wFormatTag == WAVE_FORMAT_PCM && wBitsPerSample > 16 && strcmp(ft->filetype, "wavpcm")) || wChannels > 2)
     {
       isExtensible = sox_true;
       wFmtSize += 2 + 22;
@@ -1524,7 +1524,7 @@ static int wavwritehdr(sox_format_t * ft, int second_header)
         sox_debug("Finished writing Wave file, %u data bytes %u samples",
                 dwDataLength,wav->numSamples);
         if (wFormatTag == WAVE_FORMAT_GSM610){
-            sox_debug("GSM6.10 format: %u blocks %u padded samples %u padded data bytes",
+            sox_debug("GSM6.10 format: %li blocks %u padded samples %u padded data bytes",
                     blocksWritten, dwSamplesWritten, dwDataLength);
             if (wav->gsmbytecount != dwDataLength)
                 sox_warn("help ! internal inconsistency - data_written %u gsmbytecount %u",
@@ -1535,7 +1535,7 @@ static int wavwritehdr(sox_format_t * ft, int second_header)
     return SOX_SUCCESS;
 }
 
-static sox_size_t sox_wavwrite(sox_format_t * ft, const sox_ssample_t *buf, sox_size_t len) 
+static sox_size_t sox_wavwrite(sox_format_t * ft, const sox_sample_t *buf, sox_size_t len) 
 {
         wav_t   wav = (wav_t) ft->priv;
         sox_ssize_t total_len = len;
@@ -1732,6 +1732,7 @@ static int sox_wavseek(sox_format_t * ft, sox_size_t offset)
 /* Microsoft RIFF */
 static const char *wavnames[] = {
   "wav",
+  "wavpcm",
   NULL
 };
 
