@@ -138,12 +138,13 @@ static int sox_wvestartwrite(sox_format_t * ft)
         ft->signal.encoding = SOX_ENCODING_ALAW;
         ft->signal.size = SOX_SIZE_BYTE;
         ft->signal.rate = 8000;
+        ft->signal.channels = 1;
 
         wvewriteheader(ft);
         return SOX_SUCCESS;
 }
 
-static sox_size_t sox_wvewrite(sox_format_t * ft, const sox_ssample_t *buf, sox_size_t samp)
+static sox_size_t sox_wvewrite(sox_format_t * ft, const sox_sample_t *buf, sox_size_t samp)
 {
         wve_t p = (wve_t)ft->priv;
         p->length += samp * ft->signal.size;
